/* *********************************************************************** *
 * XINX                                                                    *
 * Copyright (C) 2010 by Ulrich Van Den Hekke                              *
 * ulrich.vdh@shadoware.org                                                *
 *                                                                         *
 * This program is free software: you can redistribute it and/or modify    *
 * it under the terms of the GNU General Public License as published by    *
 * the Free Software Foundation, either version 3 of the License, or       *
 * (at your option) any later version.                                     *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.   *
 * *********************************************************************** */

#ifndef CALCDISTANCE_H
#define CALCDISTANCE_H

#include <QObject>
#include <QStringList>
#include <QDir>
#include <QUuid>
#include <QtConcurrentMap>
#include <QFutureWatcher>

class CalculDistance : public QObject
{
	Q_OBJECT
public:
	struct single_file {
		int id;
		QString filename;
		quint64 size, compressed_size;
	};
	struct pair_file {
		const QHash<int, single_file> * files;
		int id1, id2;
		quint64 compressed_size;
		double distance;
	};

	explicit CalculDistance(QStringList paths, QObject *parent = 0);
	explicit CalculDistance(const QString & uuid, QStringList paths = QStringList(), QObject *parent = 0);
	~CalculDistance();

	void setFilter(const QStringList & value);
signals:

public slots:
	void process();

	void step0_createbase();
	void step1_createfilelist();
	void step2_compresssingle();
	void step3_compresspair();

private slots:
	void singleStepFinish();
	void pairStepFinish();
	void singleStepReady(int index);
	void pairStepReady(int index);
private:
	void init();
	void stepFinish();

	struct {
		quint64 sum_size;
		quint64 sum_compressed_size;
		QFutureWatcher<single_file> * watcher;
	} m_singleFile;

	struct {
		quint64 sum_size;
		quint64 sum_compressed_size;
		QHash<int, single_file> files;
		QFutureWatcher<pair_file> * watcher;
	} m_pairFile;

	uint m_start;

	QStringList m_paths;
	QUuid m_uuid;
	QStringList m_filters;

	int m_step;
};

#endif // CALCDISTANCE_H
