/* *********************************************************************** *
 * XINX                                                                    *
 * Copyright (C) 2010 by Ulrich Van Den Hekke                              *
 * ulrich.vdh@shadoware.org                                                *
 *                                                                         *
 * This program is free software: you can redistribute it and/or modify    *
 * it under the terms of the GNU General Public License as published by    *
 * the Free Software Foundation, either version 3 of the License, or       *
 * (at your option) any later version.                                     *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.   *
 * *********************************************************************** */

#include <QtCore/QCoreApplication>
#include "calcul_distance.h"
#include <iostream>
#include <QTimer>

static void showParameters()
{
	const QString & help =
	"Utilisation : calcul_distance [OPTION]... [PATH]...\n"
	"Calcul la distance entre tous les fichiers définits dans l'ensemble des path.\n"
	"Les arguments disponbiles sont : \n"
	"  --uuid <uuid>              the file name to use to store distance. If no\n"
	"                             file name is defined, calcul_distance create one.\n"
	"  --filter <filter>          define a filter to use. This options can be given \n"
	"                             multiple times.\n";


	std::cout << help.toStdString();


	exit(1);
}


int main(int argc, char *argv[])
{
    QCoreApplication a(argc, argv);

	QStringList args = a.arguments();
	args.removeFirst();

	QString uuid;
	QStringList filters;
	QStringList paths;

	QStringListIterator argsIterator(args);
	while (argsIterator.hasNext())
	{
		const QString & arg = argsIterator.next();
		if (arg == "--uuid")
		{
			if (argsIterator.hasNext())
			{
				uuid = argsIterator.next();
			}
			else
			{
				showParameters();
			}
		}
		else if (arg == "--filter")
		{
			if (argsIterator.hasNext())
			{
				filters += argsIterator.next();
			}
			else
			{
				showParameters();
			}
		}
		else
		{
			paths += arg;
		}
	}

	CalculDistance * sorter;
	if (uuid.isEmpty())
	{
		sorter = new CalculDistance(paths);
	}
	else
	{
		sorter = new CalculDistance(uuid, paths);
	}
	sorter->setFilter(filters);

	QTimer::singleShot(0, sorter, SLOT(process()));

	return a.exec();

	// Site : http://regedit.gamedev.pl/news_1368_lzma_sdk_-_how_to_use.html
	// Find distance
	// select files1.path, files2.path, distances.distance * 100 from distances, files files1, files files2 where distances.id1=files1.id and distances.id2=files2.id order by distance desc;
}
